from setuptools import setup

setup(name='rk_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['rk_distributions'],
      author = 'Raghavendra Kulkarni',
      author_email = 'rdkulkarni@gmail.com',
      zip_safe=False)
